@@ -27,9 +27,9 @@ from lftools.cli.infofile import infofile
 from lftools.cli.jenkins import jenkins_cli
 from lftools.cli.lfidapi import lfidapi
 from lftools.cli.license import license
+from lftools.cli.nexus import nexus
 from lftools.cli.nexus2 import nexus_two
 from lftools.cli.nexus3 import nexus_three
-from lftools.cli.nexus import nexus
 from lftools.cli.rtd import rtd
 from lftools.cli.schema import schema
 from lftools.cli.sign import sign
@@ -61,7 +61,7 @@ def cli(ctx, debug, interactive, password, username):
         else:
             try:
                 username = conf.get_setting("global", "username")
-            except (configparser.NoOptionError, configparser.NoSectionError) as e:
+            except (configparser.NoOptionError, configparser.NoSectionError):
                 username = None
 
     if password is None:
@@ -70,7 +70,7 @@ def cli(ctx, debug, interactive, password, username):
         else:
             try:
                 password = conf.get_setting("global", "password")
-            except (configparser.NoOptionError, configparser.NoSectionError) as e:
+            except (configparser.NoOptionError, configparser.NoSectionError):
                 password = None
 
     ctx.obj["username"] = username
