@@ -151,6 +151,17 @@ def createproject(ctx, gerrit_fqdn, gerrit_project, ldap_group, description, che
     log.info(pformat(data))
 
 
+@click.command(name="create-saml-group")
+@click.argument("gerrit_fqdn")
+@click.argument("ldap_group")
+@click.pass_context
+def create_saml_group(ctx, gerrit_fqdn, ldap_group):
+    """Create saml group based on ldap group."""
+    g = gerrit.Gerrit(fqdn=gerrit_fqdn)
+    data = g.create_saml_group(gerrit_fqdn, ldap_group)
+    log.info(pformat(data))
+
+
 @click.command(name="list-project-permissions")
 @click.argument("gerrit_fqdn")
 @click.argument("project")
@@ -180,5 +191,6 @@ gerrit_cli.add_command(addgitreview)
 gerrit_cli.add_command(addgithubrights)
 gerrit_cli.add_command(createproject)
 gerrit_cli.add_command(abandonchanges)
+gerrit_cli.add_command(create_saml_group)
 gerrit_cli.add_command(list_project_permissions)
 gerrit_cli.add_command(list_project_inherits_from)
