@@ -10,14 +10,12 @@
 """Test deploy command."""
 
 import os
-import sys
 
 import pytest
 import requests
 
-from lftools import cli
 import lftools.deploy as deploy_sys
-
+from lftools import cli
 
 FIXTURE_DIR = os.path.join(
     os.path.dirname(os.path.realpath(__file__)),
@@ -287,7 +285,6 @@ def test_remove_duplicates_and_sort():
 def test_deploy_logs(cli_runner, datafiles, responses):
     """Test deploy_logs() command for expected upload cases."""
     os.chdir(str(datafiles))
-    workspace_dir = os.path.join(str(datafiles), "workspace")
 
     # Test successful upload
     build_url = "https://jenkins.example.org/job/builder-check-poms/204"
@@ -466,44 +463,43 @@ def test__request_post_file(responses, mocker):
     """Test _request_post_file."""
 
     zip_file = "zip-test-files/test.zip"
-    resp = {}
     test_url = "http://connection.error.test"
     exception = requests.exceptions.ConnectionError(test_url)
     responses.add(responses.POST, test_url, body=exception)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file)
+        deploy_sys._request_post_file(test_url, zip_file)
     assert "Could not connect to URL" in str(excinfo.value)
 
     test_url = "http://invalid.url.test:8081"
     exception = requests.exceptions.InvalidURL(test_url)
     responses.add(responses.POST, test_url, body=exception)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file)
+        deploy_sys._request_post_file(test_url, zip_file)
     assert "Invalid URL" in str(excinfo.value)
 
     test_url = "http://missing.schema.test:8081"
     exception = requests.exceptions.MissingSchema(test_url)
     responses.add(responses.POST, test_url, body=exception)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file)
+        deploy_sys._request_post_file(test_url, zip_file)
     assert "Not valid URL" in str(excinfo.value)
 
     test_url = "http://repository.read.only:8081"
     responses.add(responses.POST, test_url, body=None, status=400)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file)
+        deploy_sys._request_post_file(test_url, zip_file)
     assert "Repository is read only" in str(excinfo.value)
 
     test_url = "http://repository.not.found:8081"
     responses.add(responses.POST, test_url, body=None, status=404)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file)
+        deploy_sys._request_post_file(test_url, zip_file)
     assert "Did not find repository" in str(excinfo.value)
 
     test_url = "http://other.upload.error:8081"
     responses.add(responses.POST, test_url, body=None, status=500)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file)
+        deploy_sys._request_post_file(test_url, zip_file)
     assert "Failed to upload to Nexus with status code" in str(excinfo.value)
 
 
@@ -512,44 +508,43 @@ def test__request_post_file_data(responses, mocker):
 
     param = {"r": (None, "testing")}
     zip_file = "zip-test-files/test.zip"
-    resp = {}
     test_url = "http://connection.error.test"
     exception = requests.exceptions.ConnectionError(test_url)
     responses.add(responses.POST, test_url, body=exception)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file, param)
+        deploy_sys._request_post_file(test_url, zip_file, param)
     assert "Could not connect to URL" in str(excinfo.value)
 
     test_url = "http://invalid.url.test:8081"
     exception = requests.exceptions.InvalidURL(test_url)
     responses.add(responses.POST, test_url, body=exception)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file, param)
+        deploy_sys._request_post_file(test_url, zip_file, param)
     assert "Invalid URL" in str(excinfo.value)
 
     test_url = "http://missing.schema.test:8081"
     exception = requests.exceptions.MissingSchema(test_url)
     responses.add(responses.POST, test_url, body=exception)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file, param)
+        deploy_sys._request_post_file(test_url, zip_file, param)
     assert "Not valid URL" in str(excinfo.value)
 
     test_url = "http://repository.read.only:8081"
     responses.add(responses.POST, test_url, body=None, status=400)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file, param)
+        deploy_sys._request_post_file(test_url, zip_file, param)
     assert "Repository is read only" in str(excinfo.value)
 
     test_url = "http://repository.not.found:8081"
     responses.add(responses.POST, test_url, body=None, status=404)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file, param)
+        deploy_sys._request_post_file(test_url, zip_file, param)
     assert "Did not find repository" in str(excinfo.value)
 
     test_url = "http://other.upload.error:8081"
     responses.add(responses.POST, test_url, body=None, status=500)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys._request_post_file(test_url, zip_file, param)
+        deploy_sys._request_post_file(test_url, zip_file, param)
     assert "Failed to upload to Nexus with status code" in str(excinfo.value)
 
 
@@ -731,15 +726,10 @@ def test__upload_maven_file_to_nexus(responses, mocker):
     artifact_id = "ArtId2"
     version = "1.2.7"
     packaging = "tar.xz"
-    classified = None
-
-    resp = {}
 
     test_url = "http://all.ok.upload:8081"
     responses.add(responses.POST, "{}/{}".format(test_url, common_urlpart), body=None, status=201)
-    resp = deploy_sys.upload_maven_file_to_nexus(
-        test_url, nexus_repo_id, group_id, artifact_id, version, packaging, zip_file
-    )
+    deploy_sys.upload_maven_file_to_nexus(test_url, nexus_repo_id, group_id, artifact_id, version, packaging, zip_file)
 
     xml_other_error = """
         <nexus-error><errors><error>
@@ -750,7 +740,7 @@ def test__upload_maven_file_to_nexus(responses, mocker):
     test_url = "http://something.went.wrong:8081"
     responses.add(responses.POST, "{}/{}".format(test_url, common_urlpart), body=xml_other_error, status=405)
     with pytest.raises(requests.HTTPError) as excinfo:
-        resp = deploy_sys.upload_maven_file_to_nexus(
+        deploy_sys.upload_maven_file_to_nexus(
             test_url, nexus_repo_id, group_id, artifact_id, version, packaging, zip_file
         )
     assert "Something went wrong" in str(excinfo.value)
